@@ -28,6 +28,11 @@ from os_win.utils.compute import vmutils
 class VMUtilsTestCase(test_base.OsWinBaseTestCase):
     """Unit tests for the Hyper-V VMUtils class."""
 
+    _autospec_classes = [
+        vmutils.jobutils.JobUtils,
+        vmutils.pathutils.PathUtils,
+    ]
+
     _FAKE_VM_NAME = 'fake_vm'
     _FAKE_MEMORY_MB = 2
     _FAKE_VCPUS_NUM = 4
@@ -55,6 +60,12 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
     _FAKE_DYNAMIC_MEMORY_RATIO = 1.0
     _FAKE_MONITOR_COUNT = 1
 
+    _FAKE_MEMORY_INFO = {'DynamicMemoryEnabled': True,
+                         'Reservation': 1024,
+                         'Limit': 4096,
+                         'Weight': 5000,
+                         'MaxMemoryBlocksPerNumaNode': 2048}
+
     _FAKE_SUMMARY_INFO = {'NumberOfProcessors': 4,
                           'EnabledState': 2,
                           'MemoryUsage': 2,
@@ -71,8 +82,6 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
         super(VMUtilsTestCase, self).setUp()
         self._vmutils = vmutils.VMUtils()
         self._vmutils._conn_attr = mock.MagicMock()
-        self._vmutils._jobutils = mock.MagicMock()
-        self._vmutils._pathutils = mock.MagicMock()
         self._jobutils = self._vmutils._jobutils
 
     def test_get_vm_summary_info(self):
@@ -141,6 +150,21 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
     def test_set_vm_memory_dynamic(self):
         self._test_set_vm_memory_dynamic(dynamic_memory_ratio=2.0)
 
+    @mock.patch.object(_wqlutils, 'get_element_associated_class')
+    def test_get_vm_memory_info(self, mock_get_element_associated_class):
+        vmsetting = self._lookup_vm()
+
+        mock_s = mock.MagicMock(**self._FAKE_MEMORY_INFO)
+        mock_get_element_associated_class.return_value = [mock_s]
+
+        memory = self._vmutils.get_vm_memory_info(self._FAKE_VM_NAME)
+        self.assertEqual(self._FAKE_MEMORY_INFO, memory)
+
+        mock_get_element_associated_class.assert_called_once_with(
+            self._vmutils._compat_conn,
+            self._vmutils._MEMORY_SETTING_DATA_CLASS,
+            element_instance_id=vmsetting.InstanceID)
+
     @mock.patch.object(_wqlutils, 'get_element_associated_class')
     def _test_set_vm_memory_dynamic(self, mock_get_element_associated_class,
                                     dynamic_memory_ratio,
@@ -477,22 +501,21 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
                 mock_vm, self._FAKE_PATH, self._FAKE_CTRL_PATH,
                 self._FAKE_DRIVE_ADDR, constants.DISK)
 
-    @mock.patch.object(vmutils.VMUtils, '_get_new_resource_setting_data')
+    @mock.patch.object(vmutils.VMUtils, 'attach_drive')
     @mock.patch.object(vmutils.VMUtils, '_get_vm_ide_controller')
-    def test_attach_ide_drive(self, mock_get_ide_ctrl, mock_get_new_rsd):
+    def test_attach_ide_drive(self, mock_get_ide_ctrl, mock_attach_drive):
         mock_vm = self._lookup_vm()
-        mock_rsd = mock_get_new_rsd.return_value
 
         self._vmutils.attach_ide_drive(self._FAKE_VM_NAME,
                                        self._FAKE_CTRL_PATH,
                                        self._FAKE_CTRL_ADDR,
                                        self._FAKE_DRIVE_ADDR)
 
-        self._vmutils._jobutils.add_virt_resource.assert_called_with(
-            mock_rsd, mock_vm)
-
         mock_get_ide_ctrl.assert_called_with(mock_vm, self._FAKE_CTRL_ADDR)
-        self.assertTrue(mock_get_new_rsd.called)
+        mock_attach_drive.assert_called_once_with(
+            self._FAKE_VM_NAME, self._FAKE_CTRL_PATH,
+            mock_get_ide_ctrl.return_value, self._FAKE_DRIVE_ADDR,
+            constants.DISK)
 
     @ddt.data(constants.DISK, constants.DVD)
     @mock.patch.object(vmutils.VMUtils, '_get_new_resource_setting_data')
@@ -713,6 +736,30 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
         self._vmutils._jobutils.remove_virt_resource.assert_called_once_with(
             mock_nic_data)
 
+    @mock.patch.object(vmutils.VMUtils, '_lookup_vm_check')
+    @mock.patch.object(_wqlutils, 'get_element_associated_class')
+    def test_get_vm_nics(self, mock_get_assoc, mock_lookup_vm):
+        vnics = self._vmutils._get_vm_nics(mock.sentinel.vm_name)
+
+        self.assertEqual(mock_get_assoc.return_value, vnics)
+        mock_lookup_vm.assert_called_once_with(mock.sentinel.vm_name)
+        mock_get_assoc.assert_called_once_with(
+            self._vmutils._compat_conn,
+            self._vmutils._SYNTHETIC_ETHERNET_PORT_SETTING_DATA_CLASS,
+            element_instance_id=mock_lookup_vm.return_value.InstanceId)
+
+    @mock.patch.object(vmutils.VMUtils, '_get_vm_nics')
+    def test_get_vm_nic_names(self, mock_get_vm_nics):
+        exp_nic_names = ['port1', 'port2']
+
+        mock_get_vm_nics.return_value = [
+            mock.Mock(ElementName=nic_name)
+            for nic_name in exp_nic_names]
+        nic_names = self._vmutils.get_vm_nic_names(mock.sentinel.vm_name)
+
+        self.assertEqual(exp_nic_names, nic_names)
+        mock_get_vm_nics.assert_called_once_with(mock.sentinel.vm_name)
+
     def test_set_vm_state(self):
         mock_vm = self._lookup_vm()
         mock_vm.RequestStateChange.return_value = (
@@ -1201,7 +1248,8 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
 
         self._vmutils.stop_vm_jobs(mock.sentinel.vm_name)
 
-        self._vmutils._jobutils.stop_jobs.assert_called_once_with(mock_vm)
+        self._vmutils._jobutils.stop_jobs.assert_called_once_with(
+            mock_vm, None)
 
     def test_set_secure_boot(self):
         vs_data = mock.MagicMock()
@@ -1501,6 +1549,24 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
     def test_remove_all_pci_devices(self):
         self._vmutils.remove_all_pci_devices(mock.sentinel.vm_name)
 
+    def test_populate_fsk(self):
+        self.assertRaises(NotImplementedError,
+                          self._vmutils.populate_fsk,
+                          mock.sentinel.fsk_filepath,
+                          mock.sentinel.fsk_pairs)
+
+    def test_add_vtpm(self):
+        self.assertRaises(NotImplementedError,
+                          self._vmutils.add_vtpm,
+                          mock.sentinel.vm_name, mock.sentinel.pdk_filepath,
+                          mock.sentinel.shielded)
+
+    def test_provision_vm(self):
+        self.assertRaises(NotImplementedError,
+                          self._vmutils.provision_vm,
+                          mock.sentinel.vm_name, mock.sentinel.fsk_filepath,
+                          mock.sentinel.pdk_filepath)
+
 
 class VMUtils6_3TestCase(test_base.OsWinBaseTestCase):
 
