@@ -18,7 +18,9 @@ import mock
 from os_win import exceptions
 from os_win.tests.unit import test_base
 from os_win.utils import _wqlutils
+from os_win.utils.compute import vmutils
 from os_win.utils.metrics import metricsutils
+from os_win import utilsfactory
 
 
 class MetricsUtilsTestCase(test_base.OsWinBaseTestCase):
@@ -27,8 +29,16 @@ class MetricsUtilsTestCase(test_base.OsWinBaseTestCase):
     _FAKE_RET_VAL = 0
     _FAKE_PORT = "fake's port name"
 
+    _autospec_classes = [
+        vmutils.VMUtils,
+    ]
+
     def setUp(self):
         super(MetricsUtilsTestCase, self).setUp()
+
+        mock.patch.object(utilsfactory, 'get_vmutils',
+                          mock.Mock(return_value=vmutils.VMUtils)).start()
+
         self.utils = metricsutils.MetricsUtils()
         self.utils._conn_attr = mock.MagicMock()
 
@@ -58,6 +68,22 @@ class MetricsUtilsTestCase(test_base.OsWinBaseTestCase):
         mock_enable_metrics.assert_has_calls(
             [mock.call(mock_disk), mock.call(mock_vm, metrics_names)])
 
+    @mock.patch.object(metricsutils.MetricsUtils, '_enable_metrics')
+    def test_enable_disk_metrics_collection(self, mock_enable_metrics):
+        mock_get_disk = (
+            self.utils._vmutils._get_mounted_disk_resource_from_path)
+
+        self.utils.enable_disk_metrics_collection(
+            mock.sentinel.disk_path,
+            mock.sentinel.is_physical,
+            mock.sentinel.serial)
+
+        mock_get_disk.assert_called_once_with(
+            mock.sentinel.disk_path,
+            is_physical=mock.sentinel.is_physical,
+            serial=mock.sentinel.serial)
+        mock_enable_metrics.assert_called_once_with(mock_get_disk.return_value)
+
     @mock.patch.object(metricsutils.MetricsUtils, '_enable_metrics')
     @mock.patch.object(metricsutils.MetricsUtils, '_get_switch_port')
     def test_enable_switch_port_metrics_collection(self, mock_get_port,
@@ -72,6 +98,7 @@ class MetricsUtilsTestCase(test_base.OsWinBaseTestCase):
 
     def _check_enable_metrics(self, metrics=None, definition=None):
         mock_element = mock.MagicMock()
+        self.utils._metrics_svc.ControlMetrics.return_value = [0]
 
         self.utils._enable_metrics(mock_element, metrics)
 
@@ -90,6 +117,17 @@ class MetricsUtilsTestCase(test_base.OsWinBaseTestCase):
         self._check_enable_metrics([metrics_name, mock.sentinel.metrics_name],
                                    metrics_def.path_.return_value)
 
+    def test_enable_metrics_exception(self):
+        metric_name = self.utils._CPU_METRICS
+        metric_def = mock.MagicMock()
+        self.utils._metrics_defs_obj = {metric_name: metric_def}
+
+        self.utils._metrics_svc.ControlMetrics.return_value = [1]
+        self.assertRaises(exceptions.OSWinException,
+                          self.utils._enable_metrics,
+                          mock.MagicMock(),
+                          [metric_name])
+
     @mock.patch.object(metricsutils.MetricsUtils, '_get_metrics')
     @mock.patch.object(metricsutils.MetricsUtils, '_get_vm_resources')
     @mock.patch.object(metricsutils.MetricsUtils, '_get_vm')
@@ -376,7 +414,7 @@ class MetricsUtilsTestCase(test_base.OsWinBaseTestCase):
         result = self.utils._get_switch_port(mock.sentinel.port_name)
 
         self.assertEqual(mock_unique_result.return_value, result)
-        conn_class = self.utils._conn.Msvm_SyntheticEthernetPortSettingData
+        conn_class = self.utils._conn.Msvm_EthernetPortAllocationSettingData
         conn_class.assert_called_once_with(ElementName=mock.sentinel.port_name)
         mock_unique_result.assert_called_once_with(conn_class.return_value,
                                                    mock.sentinel.port_name)
