@@ -72,6 +72,8 @@ class NetworkUtilsTestCase(test_base.OsWinBaseTestCase):
         self.assertEqual({}, self.netutils._switches)
 
     def test_init_caches(self):
+        self.netutils._enable_cache = True
+
         self.netutils._switches = {}
         self.netutils._switch_ports = {}
         self.netutils._vlan_sds = {}
@@ -125,6 +127,8 @@ class NetworkUtilsTestCase(test_base.OsWinBaseTestCase):
         self.assertEqual({}, self.netutils._switch_ports)
 
     def test_update_cache(self):
+        self.netutils._enable_cache = True
+
         self.netutils._switch_ports[mock.sentinel.other] = mock.sentinel.port
         conn = self.netutils._conn
         mock_port = mock.MagicMock(ElementName=mock.sentinel.port_name)
@@ -209,9 +213,12 @@ class NetworkUtilsTestCase(test_base.OsWinBaseTestCase):
     def test_get_vnic_event_listener(self, mock_get_event_query,
                                      mock_execute, mock_patcher):
         event = mock.MagicMock()
+        # This event should be ignored.
+        unnamed_port_event = mock.MagicMock(ElementName=None)
         port_class = self.netutils._conn.Msvm_SyntheticEthernetPortSettingData
         wmi_event_listener = port_class.watch_for.return_value
-        mock_execute.side_effect = [exceptions.x_wmi_timed_out, event]
+        mock_execute.side_effect = [exceptions.x_wmi_timed_out,
+                                    unnamed_port_event, event]
 
         # callback will raise an exception in order to stop iteration in the
         # listener.
@@ -229,7 +236,7 @@ class NetworkUtilsTestCase(test_base.OsWinBaseTestCase):
             mock_get_event_query.return_value)
         mock_execute.assert_has_calls(
             [mock.call(wmi_event_listener,
-                       self.netutils._VNIC_LISTENER_TIMEOUT_MS)] * 2)
+                       self.netutils._VNIC_LISTENER_TIMEOUT_MS)] * 3)
         callback.assert_called_once_with(event.ElementName)
 
     def test_get_event_wql_query(self):
