@@ -237,12 +237,29 @@ class VMUtils(baseutils.BaseUtilsVirt):
         vm = self._lookup_vm_check(vm_name, as_vssd=False)
         return vm.Name
 
-    def _set_vm_memory(self, vmsetting, memory_mb, memory_per_numa_node,
-                       dynamic_memory_ratio):
+    def get_vm_memory_info(self, vm_name):
+        vmsetting = self._lookup_vm_check(vm_name)
+        memory = self._get_vm_memory(vmsetting)
+
+        memory_info_dict = {
+            'DynamicMemoryEnabled': memory.DynamicMemoryEnabled,
+            'Reservation': memory.Reservation,
+            'Limit': memory.Limit,
+            'Weight': memory.Weight,
+            'MaxMemoryBlocksPerNumaNode': memory.MaxMemoryBlocksPerNumaNode,
+        }
+        return memory_info_dict
+
+    def _get_vm_memory(self, vmsetting):
         mem_settings = _wqlutils.get_element_associated_class(
             self._compat_conn, self._MEMORY_SETTING_DATA_CLASS,
             element_instance_id=vmsetting.InstanceID)[0]
 
+        return mem_settings
+
+    def _set_vm_memory(self, vmsetting, memory_mb, memory_per_numa_node,
+                       dynamic_memory_ratio):
+        mem_settings = self._get_vm_memory(vmsetting)
         max_mem = int(memory_mb)
         mem_settings.Limit = max_mem
 
@@ -628,6 +645,18 @@ class VMUtils(baseutils.BaseUtilsVirt):
                       "to remove vm nic: '%s'. It may have been already "
                       "deleted.", nic_name)
 
+    def _get_vm_nics(self, vm_name):
+        vmsettings = self._lookup_vm_check(vm_name)
+        nics = _wqlutils.get_element_associated_class(
+            self._compat_conn,
+            self._SYNTHETIC_ETHERNET_PORT_SETTING_DATA_CLASS,
+            element_instance_id=vmsettings.InstanceId)
+        return nics
+
+    def get_vm_nic_names(self, vm_name):
+        nics = self._get_vm_nics(vm_name)
+        return [nic.ElementName for nic in nics]
+
     def soft_shutdown_vm(self, vm_name):
         vm = self._lookup_vm_check(vm_name, as_vssd=False)
         shutdown_component = self._conn.Msvm_ShutdownComponent(
@@ -985,9 +1014,9 @@ class VMUtils(baseutils.BaseUtilsVirt):
             pass
         return constants.VM_GEN_1
 
-    def stop_vm_jobs(self, vm_name):
+    def stop_vm_jobs(self, vm_name, timeout=None):
         vm = self._lookup_vm_check(vm_name, as_vssd=False)
-        self._jobutils.stop_jobs(vm)
+        self._jobutils.stop_jobs(vm, timeout)
 
     def enable_secure_boot(self, vm_name, msft_ca_required):
         """Enables Secure Boot for the instance with the given name.
@@ -1225,6 +1254,33 @@ class VMUtils(baseutils.BaseUtilsVirt):
         # Supported on Windows Server 2016 or newer.
         pass
 
+    def populate_fsk(self, fsk_filepath, fsk_pairs):
+        """Writes the given FSK pairs into the give file.
+
+        :raises NotImplementedError: This method is required for Shielded VMs,
+            which is supported on Windows / Hyper-V Server 2016 or newer.
+        """
+        raise NotImplementedError(_('This method is supported on Windows / '
+                                    'Hyper-V Server 2016 or newer'))
+
+    def add_vtpm(self, vm_name, pdk_filepath, shielded):
+        """Adds a vtpm and enables it with encryption or shielded option.
+
+        :raises NotImplementedError: This method is required for Shielded VMs,
+            which is supported on Windows / Hyper-V Server 2016 or newer.
+        """
+        raise NotImplementedError(_('This method is supported on Windows / '
+                                    'Hyper-V Server 2016 or newer'))
+
+    def provision_vm(self, vm_name, fsk_filepath, pdk_filepath):
+        """Provisions the given VM with the given FSK and PDK files.
+
+        :raises NotImplementedError: This method is required for Shielded VMs,
+            which is supported on Windows / Hyper-V Server 2016 or newer.
+        """
+        raise NotImplementedError(_('This method is supported on Windows / '
+                                    'Hyper-V Server 2016 or newer'))
+
 
 class VMUtils6_3(VMUtils):
 
